# Color Generator ![alt text](https://www.python.org/static/community_logos/python-powered-w-100x40.png)
Handle color calculation in a pythonic way !

## Installation
https://pypi.org/project/colorGenerator/  
Install from Pypi :
```bash
pip install colorGenerator
```
Import into your code and ready to go
```python
import colorGenerator as cG
```
### Uploading the distribution archives
You can use twine to upload the distribution packages. You’ll need to install Twine:
```bash
pip install --upgrade twine
```
Once installed, run Twine to upload all of the archives under dist:
```bash
twine upload dist/*
```